// Unreal Fighting Framework by Kevin Poretti

#include "FFPlayerController.h"

// FF includes
#include "FFInputBufferComponent.h"

// UE includes
#include "EnhancedInputSubsystems.h"

AFFPlayerController::AFFPlayerController()
{
    InputBuffer = CreateDefaultSubobject<UFFInputBufferComponent>(TEXT("InputBuffer"));
}


void AFFPlayerController::SendInputsToRemote() const
{
}


void AFFPlayerController::ModifyRawInput()
{
    ModifiedInput = RawInput;
}


void AFFPlayerController::FixedTick(float OneFrame)
{
    //UnacknowledgedInputs.Push(RawInput);
    InputBuffer->AddInput(ModifiedInput);
    //SendInputsToRemote();
}

bool AFFPlayerController::CheckInputSequence(const FFFInputSequence& InInputSequence)
{
    return InputBuffer->CheckInputSequence(InInputSequence);
}


bool AFFPlayerController::CheckInputSequences(const TArray<FFFInputSequence>& InputSequences)
{
    // no input conditions to check
    if(InputSequences.IsEmpty())
    {
        return true;
    }

    for(const FFFInputSequence& ThisInputSequence : InputSequences)
    {
        if(InputBuffer->CheckInputSequence(ThisInputSequence))
        {
            return true;
        }
    }
    return false;
}

void AFFPlayerController::DisableMostRecentInput()
{
    InputBuffer->DisableMostRecentInput();
}


void AFFPlayerController::SetupInputComponent()
{
    Super::SetupInputComponent();

    if (ULocalPlayer* LocalPlayer = Cast<ULocalPlayer>(Player))
    {
        if (UEnhancedInputLocalPlayerSubsystem* InputSystem = LocalPlayer->GetSubsystem<UEnhancedInputLocalPlayerSubsystem>())
        {
            if (!DefaultInputMapping.IsNull())
            {
                InputSystem->AddMappingContext(DefaultInputMapping.LoadSynchronous(), 0);
            }
        }
    }
}
